# Changelog

<!--next-version-placeholder-->

## v1.9.0 (2021-05-11)
### Feature
* **interp1d_unc:** Add cubic bspline interpolation-kind ([`f0c6d19`](https://github.com/PTB-PSt1/PyDynamic/commit/f0c6d19bad71816f5c6d95803f734e77567931ea))

### Documentation
* **interp1d_unc:** Add example for kind = "cubic" ([`8c2ce38`](https://github.com/PTB-PSt1/PyDynamic/commit/8c2ce38af4cb4a391da9e82c23c5754f494892ad))

## v1.8.0 (2021-04-28)
### Feature
* **propagate_convolution:** Convolution with full covariance propagation ([`299165e`](https://github.com/PTB-PSt1/PyDynamic/commit/299165ef630ef54bcb877e8a3260038805609e4f))

### Documentation
* **propagate_convolution:** Add module description ([`ffafa00`](https://github.com/PTB-PSt1/PyDynamic/commit/ffafa00ea8961bdd4e4414645102f6870063f3d7))
* **DFT_deconv:** Improve wording of docstring for return value ([`e866aa4`](https://github.com/PTB-PSt1/PyDynamic/commit/e866aa41212767f9b24f966bfabf005c9f6cdf39))

## v1.7.0 (2021-02-16)
### Feature
* **FIRuncFilter:** Add FIR filter with full covariance support ([`b937a8b`](https://github.com/PTB-PSt1/PyDynamic/commit/b937a8b979f947df3149aeda38401b90fc522ef4))

### Documentation
* **trimOrPad:** Enhance docstring ([`4c0da58`](https://github.com/PTB-PSt1/PyDynamic/commit/4c0da58e2c9d2bcae212a757f7b80ef65f602cd1))
* **_fir_filter:** Adjust docstring and ValueError ([`090b8f8`](https://github.com/PTB-PSt1/PyDynamic/commit/090b8f832c54e4cb969de70d5825d5000410eacc))

## v1.6.1 (2020-10-29)
### Fix
* Flip theta in uncertainty formulas of FIRuncFilter ([`dd04eea`](https://github.com/PTB-PSt1/PyDynamic/commit/dd04eeace70ce4fe7a81fb432cc117f80af74d4f))
